@@ -25,6 +25,16 @@ class ArticleAdmin(TendenciBaseModelAdmin):
                 'timezone',
                 )
             }),
+        ('Author', {
+            'fields': ('first_name',
+                     'last_name',
+                     'google_profile',
+                     'phone',
+                     'fax',
+                     'email',
+                     ),
+                    'classes': ('contact',),
+        }),
         ('Permissions', {'fields': ('allow_anonymous_view',)}),
         ('Advanced Permissions', {'classes': ('collapse',), 'fields': (
             'user_perms',
