@@ -101,6 +101,7 @@ class CorpMembershipAppAdmin(admin.ModelAdmin):
                            'description',
                            'confirmation_text', 'notes',
                            'corp_memb_type', 'payment_methods',
+                           'include_tax', 'tax_rate',
                            'memb_app'
                            )},),
         ('Permissions', {'fields': ('allow_anonymous_view',)}),
@@ -122,6 +123,7 @@ class CorpMembershipAppAdmin(admin.ModelAdmin):
             '%sjs/jquery_ui_all_custom/jquery-ui-1.8.5.custom.min.js' % settings.STATIC_URL,
             '%sjs/admin/corpmembershipapp_tabular_inline_ordering.js' % settings.STATIC_URL,
             '%sjs/global/tinymce.event_handlers.js' % settings.STATIC_URL,
+            '%sjs/tax_fields.js' % settings.STATIC_URL,
         )
         css = {'all': ['%scss/admin/dynamic-inlines-with-sort.css' % settings.STATIC_URL,
                        '%scss/corpmemberships-admin.css' % settings.STATIC_URL], }
