@@ -8,9 +8,10 @@ from tendenci.addons.industries.forms import IndustryForm
 class IndustryAdmin(TendenciBaseModelAdmin):
     list_display = ['industry_name', 'industry_code',
                     'owner_link', 'admin_perms',
-                    'admin_status']
+                    'admin_status', 'position']
     list_filter = ['status_detail', 'owner_username']
     search_fields = ['industry_name', 'industry_code']
+    list_editable = ['position']
     fieldsets = (
         ('Industry Information', {
             'fields': ('industry_name',
@@ -29,6 +30,17 @@ class IndustryAdmin(TendenciBaseModelAdmin):
             )}),
         )
     form = IndustryForm
-    ordering = ['-update_dt']
+    ordering = ['position']
+
+    class Media:
+        css = {
+            "all": ("css/websymbols.css",)
+        }
+        js = (
+            'js/jquery-1.6.2.min.js',
+            'js/jquery-ui-1.8.17.custom.min.js',
+            'js/admin/admin-list-reorder.js',
+            'js/global/tinymce.event_handlers.js',
+        )
 
 admin.site.register(Industry, IndustryAdmin)
