@@ -5,6 +5,10 @@ from south.v2 import SchemaMigration
 from django.db import models
 
 class Migration(SchemaMigration):
+    depends_on = (
+        ('invoices', '0001_initial'),
+        ('payments', '0001_initial'),
+    )
 
     def forwards(self, orm):
         
