@@ -2,7 +2,9 @@ from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('tendenci.apps.invoices.views',  
     url(r'^$',                                'search', name="invoices"),
-    url(r'^export/',                          'export', name="invoice.export"),
+    url(r'^export/$',                          'export', name="invoice.export"),
+    url(r"^export/status/(?P<identifier>\d+)/$", "export_status", name="invoice.export_status"),
+    url(r"^export/download/(?P<identifier>\d+)/$", "export_download", name="invoice.export_download"),
     url(r'^(?P<id>\d+)/(?P<guid>[\d\w-]+)?$', 'view', name="invoice.view"),
     url(r'^print/(?P<id>\d+)/(?P<guid>[\d\w-]+)?$', 'view',
         {'template_name': 'invoices/print_view.html'}, name="invoice.print_view"),
