@@ -85,6 +85,14 @@ class BasePage(TendenciBaseModel):
 
 
 class Page(BasePage):
+    CONTRIBUTOR_AUTHOR = 1
+    CONTRIBUTOR_PUBLISHER = 2
+    CONTRIBUTOR_CHOICES = ((CONTRIBUTOR_AUTHOR, 'Author'),
+                           (CONTRIBUTOR_PUBLISHER, 'Publisher'))
+
+    contributor_type = models.IntegerField(choices=CONTRIBUTOR_CHOICES,
+                                           default=CONTRIBUTOR_AUTHOR)
+    google_profile = models.URLField(_('Google+ URL'), blank=True)
     perms = generic.GenericRelation(ObjectPermission,
                                       object_id_field="object_id",
                                       content_type_field="content_type")
@@ -109,6 +117,14 @@ class Page(BasePage):
     def get_version_url(self, hash):
         return ("page.version", [hash])
 
+    @property
+    def has_google_author(self):
+        return self.contributor_type == self.CONTRIBUTOR_AUTHOR
+
+    @property
+    def has_google_publisher(self):
+        return self.contributor_type == self.CONTRIBUTOR_PUBLISHER
+
 
 class HeaderImage(File):
     pass
