@@ -144,7 +144,7 @@ class ProfileForm(TendenciBaseForm):
                                widget=forms.Textarea(attrs={'rows':'3'}))
     admin_notes = forms.CharField(label=_("Admin Notes"), max_length=1000, required=False,
                                widget=forms.Textarea(attrs={'rows':'3'}))
-    language = forms.ChoiceField(initial="en-us", choices=(('en-us', u'English'),))
+    language = forms.ChoiceField(initial="en", choices=settings.LANGUAGES)
     dob = forms.DateField(required=False, widget=SelectDateWidget(None, range(1920, THIS_YEAR)))
 
     status_detail = forms.ChoiceField(
@@ -189,6 +189,7 @@ class ProfileForm(TendenciBaseForm):
                   'ssn',
                   'spouse',
                   'time_zone',
+                  'language',
                   'department',
                   'education',
                   'student',
@@ -343,7 +344,7 @@ class ProfileAdminForm(TendenciBaseForm):
     interactive = forms.ChoiceField(initial=1, choices=((1,'Interactive'),
                                                           (0,'Not Interactive (no login)'),))
 
-    language = forms.ChoiceField(initial="en-us", choices=settings.LANGUAGES)
+    language = forms.ChoiceField(initial="en", choices=settings.LANGUAGES)
 
     status_detail = forms.ChoiceField(
         choices=(('active','Active'),('inactive','Inactive'), ('pending','Pending'),))
@@ -387,6 +388,7 @@ class ProfileAdminForm(TendenciBaseForm):
                   'ssn',
                   'spouse',
                   'time_zone',
+                  'language',
                   'department',
                   'education',
                   'student',
