@@ -5,6 +5,7 @@ from django.shortcuts import render_to_response
 from django.template import RequestContext
 
 from tendenci.apps.search.forms import ModelSearchForm
+from tendenci.core.event_logs.models import EventLog
 
 RESULTS_PER_PAGE = getattr(settings, 'HAYSTACK_SEARCH_RESULTS_PER_PAGE', 20)
 
@@ -45,6 +46,8 @@ class SearchView(object):
         self.form = self.build_form()
         self.query = self.get_query()
         self.results = self.get_results()
+        # log an event
+        EventLog.objects.log(action='global_search')
         
         return self.create_response()
     
