@@ -65,10 +65,12 @@ class EmailVerificationWidget(MultiWidget):
         email0_attrs['class'] = email_class_0
         email0_attrs['maxlength'] = 75
         email0_attrs['title'] = 'Email'
+        email0_attrs['placeholder'] = 'Email'
         email1_attrs = attrs.copy()
         email1_attrs['class'] = email_class_1
         email1_attrs['maxlength'] = 75
         email1_attrs['title'] = 'Confirm Email'
+        email1_attrs['placeholder'] = 'Confirm Email'
 
         widgets = (TextInput(attrs=email0_attrs),
                    TextInput(attrs=email1_attrs))
