@@ -1,13 +1,14 @@
-import datetime
 import os
+import re
 import shutil
 import zipfile
-
+import datetime
 from django.conf import settings
 from django.core.files.base import ContentFile
 from django.core.files.storage import default_storage
 from django.template.loader import render_to_string
 from django.template import RequestContext
+from tendenci.core.site_settings.utils import get_setting
 
 
 def get_start_dt(duration_days, end_dt=None):
@@ -120,6 +121,32 @@ def newsletter_jobs_list(request, jobs_days, simplified):
     return jobs, job_content
 
 
+def newsletter_events_list(request, start_dt, end_dt, simplified):
+    events = []
+    event_content = u''
+    try:
+        from tendenci.addons.events.models import Event
+
+        events = Event.objects.filter(
+            start_dt=start_dt,
+            end_dt=end_dt,
+            status_detail='active',
+            status=True,
+            allow_anonymous_view=True).order_by('start_dt')
+
+        event_content = render_to_string(
+            'newsletters/events_list.txt', {
+            'events': events,
+            'start_dt': start_dt,
+            'end_dt': end_dt,
+            'simplified':simplified},
+            context_instance=RequestContext(request))
+
+    except ImportError:
+        pass
+    return events, event_content
+
+
 def extract_files(template):
     if template.zip_file:
         zip_file = zipfile.ZipFile(template.zip_file.file)
@@ -142,3 +169,19 @@ def extract_files(template):
                                 'newsletters',
                                 template.template_id)
             zip_file.extractall(path)
+
+
+def apply_template_media(template):
+    """
+    Prepends files in content to the media path
+    of a given template's zip file contents
+    """
+    site_url = get_setting('site', 'global', 'siteurl')
+    content = unicode(template.html_file.file.read(), "utf-8")
+    pattern = r'"[^"]*?\.(?:(?i)jpg|(?i)jpeg|(?i)png|(?i)gif|(?i)bmp|(?i)tif|(?i)css)"'
+    repl = lambda x: '"%s/%s/%s"' % (
+        site_url,
+        template.get_media_url(),
+        x.group(0).replace('"', ''))
+    new_content = re.sub(pattern, repl, content)
+    return new_content
