@@ -80,7 +80,7 @@ if "postgresql" in DATABASES['default']['ENGINE']:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
 # although not all choices may be available on all operating systems.
 # In a Windows environment this must be set to your system time zone.
-TIME_ZONE = env('TIME_ZONE', 'America/Chicago')
+TIME_ZONE = env('TIME_ZONE', 'US/Central')
 
 # Language code for this installation. All choices can be found here:
 # http://www.i18nguy.com/unicode/language-identifiers.html
